Learn R Programming

saccades (version 0.1-1)

calculate.summary: Calculate Summary Statistics for a Set of Fixations.

Description

Calculates summary statistics about the trials and fixations in the given data frame.

Usage

calculate.summary(fixations)

Arguments

fixations
a data frame containing the fixations that were detected in the samples. See detect.fixations for details about the format.

Value

A data frame containing the statistics.

Details

Calculates the number of trials, the average duration of trials, the average number of fixations in trials, the average duration of the fixations, the average spatial dispersion in the fixations, and the average peak velocity that occurred during fixations. Where appropriate standard deviations are given as well. Use round to obtain a more readable version of the resulting data frame.

See Also

diagnostic.plot, detect.fixations

Examples

Run this code
data(fixations)
stats <- calculate.summary(fixations)
round(stats, digits=2)

Run the code above in your browser using DataLab