fixations: Fixations Detected in a Stream of Raw Positions
Description
Fixations detected in a stream of raw eye positions. The
corresponding raw eye positions samples are found in the data frame
samples also part of this package.
Format
a data frame containing one line per fixation. The
fixations are sorted in chronological order. Time is given in
milliseconds, x- and y-coordinates in screen pixels.Source
Recorded with an iViewX Eye-Tracker by SMI at approximately
250 Hz.